# CSRs

## Bus

```{eval-rst}

.. autoclass:: torii.lib.soc.csr.bus.Element
.. autoclass:: torii.lib.soc.csr.bus.Interface
.. autoclass:: torii.lib.soc.csr.bus.Decoder
.. autoclass:: torii.lib.soc.csr.bus.Multiplexer

```

## Events

```{eval-rst}

.. autoclass:: torii.lib.soc.csr.event.EventMonitor

```

## Wishbone

```{eval-rst}

.. autoclass:: torii.lib.soc.csr.wishbone.WishboneCSRBridge

```
